pub struct CheckboxState {
pub area: Rect,
pub inner: Rect,
pub check_area: Rect,
pub text_area: Rect,
pub behave_check: CheckboxCheck,
pub checked: bool,
pub default: bool,
pub focus: FocusFlag,
pub mouse: MouseFlags,
pub non_exhaustive: NonExhaustive,
}Expand description
State.
Fields
area: RectComplete area read only. renewed for each render.
inner: RectArea inside the block. read only. renewed for each render.
check_area: RectArea of the check mark. read only. renewed for each render.
text_area: RectArea for the text. read only. renewed for each render.
behave_check: CheckboxCheckBehaviour for check. read only. renewed for each render.
checked: boolChecked state. read+write
default: boolDefault state. read+write Maybe overriden by a default set for the widget.
focus: FocusFlagCurrent focus state. read+write
mouse: MouseFlagsMouse helper read+write
non_exhaustive: NonExhaustiveImplementations
Sourceimpl CheckboxState
impl CheckboxState
pub fn new() -> Self
pub fn named(name: &str) -> Self
Sourcepub fn set_checked(&mut self, checked: bool) -> bool
pub fn set_checked(&mut self, checked: bool) -> bool
Set the value.
Sourcepub fn set_default(&mut self, default: bool) -> bool
pub fn set_default(&mut self, default: bool) -> bool
Set the default value.
Sourcepub fn set_value(&mut self, checked: bool) -> bool
pub fn set_value(&mut self, checked: bool) -> bool
Set checked value. Always sets default to false.
Sourcepub fn flip_checked(&mut self)
pub fn flip_checked(&mut self)
Flip the checkbox. If it was in default state it just switches off the default flag. Otherwise, it flips true/false.