Navigation

Enum Navigation 

pub enum Navigation {
    None,
    Lock,
    Mouse,
    Leave,
    Reach,
    ReachLeaveFront,
    ReachLeaveBack,
    Regular,
}
Focus navigation for widgets.

The effects that hinder focus-change (Reach*, Lock) only work when navigation changes via next()/prev()/focus_at().

Programmatic focus changes are always possible.

Variants



None

Widget is not reachable with normal keyboard or mouse navigation.



Lock

Focus is locked to stay with this widget. No mouse or keyboard navigation can change that.



Mouse

Widget is not reachable with keyboard navigation, but can be focused with the mouse.



Leave

Widget cannot be reached with normal keyboard navigation, but can be left. (e.g. Tabs, Split-Divider)



Reach

Widget can be reached with normal keyboard navigation, but not left. (e.g. TextArea)



ReachLeaveFront

Widget can be reached with normal keyboard navigation, but only be left with backward navigation. (e.g. some widget with internal structure)



ReachLeaveBack

Widget can be reached with normal keyboard navigation, but only be left with forward navigation. (e.g. some widget with internal structure)



Regular

Widget can be reached and left with normal keyboard and mouse navigation.