pub struct MenubarState {
pub area: Rect,
pub bar: MenuLineState,
pub popup: PopupMenuState,
pub non_exhaustive: NonExhaustive,
/* private fields */
}Expand description
State & event-handling.
Fields
area: RectArea for the main-menubar. readonly. renewed for each render.
bar: MenuLineStateState for the menu.
popup: PopupMenuStateState for the last rendered popup menu.
non_exhaustive: NonExhaustiveImplementations
Sourceimpl MenubarState
impl MenubarState
Sourcepub fn new() -> MenubarState
pub fn new() -> MenubarState
State.
For the specifics use the public fields menu and popup.
Sourcepub fn named(name: &'static str) -> MenubarState
pub fn named(name: &'static str) -> MenubarState
New state with a focus name.
Sourcepub fn popup_active(&self) -> bool
pub fn popup_active(&self) -> bool
Submenu visible/active.
Sourcepub fn set_popup_active(&mut self, active: bool)
pub fn set_popup_active(&mut self, active: bool)
Submenu visible/active.
Sourcepub fn set_popup_z(&mut self, z: u16)
pub fn set_popup_z(&mut self, z: u16)
Set the z-value for the popup-menu.
This is the z-index used when adding the menubar to the focus list.