SplitType

Enum SplitType 

pub enum SplitType {
    FullEmpty,
    FullPlain,
    FullDouble,
    FullThick,
    FullQuadrantInside,
    FullQuadrantOutside,
    Scroll,
    Widget,
}
Render variants for the splitter.

Variants



FullEmpty

Render a full splitter between the widgets. Reduces the area for each widget. Renders a blank border.



FullPlain

Render a full splitter between the widgets. Reduces the area for each widget. Renders a plain line border.



FullDouble

Render a full splitter between the widgets. Reduces the area for each widget. Renders a double line border.



FullThick

Render a full splitter between the widgets. Reduces the area for each widget. Renders a thick line border.



FullQuadrantInside

Render a full splitter between the widgets. Reduces the area for each widget. Renders a border with a single line on the inside of a half block.



FullQuadrantOutside

Render a full splitter between the widgets. Reduces the area for each widget. Renders a border with a single line on the outside of a half block.



Scroll

Render a minimal splitter, consisting just the two marker chars rendered over the left/top widget.

If the left widget has a Scroll in that area this will integrate nicely. You will have to set start_margin with Scroll, then Scroll can adjust its rendering to leave space for the markers. And you want to set a mark_offset here.

The widget will get the full area, only the marker is used for mouse interactions.



Widget

Don’t render a splitter, fully manual mode.

The widget will have the full area, but the event-handling will use the last column/row of the widget for moving the split. This can be adjusted if you change state.split[n] which provides the active area.

Implementations

Source

impl SplitType

pub fn is_full(&self) -> bool