SkipLine

Trait SkipLine 

pub trait SkipLine: Iterator {
    // Required methods
    fn skip_line(&mut self) -> Result<(), TextError>;
    fn skip_to(&mut self, byte_pos: usize) -> Result<(), TextError>;
}
Extended Iterator that can skip over parts of the underlying data.

Required Methods

fn skip_line(&mut self) -> Result<(), TextError>

Set the iterator to the start of the next line.

fn skip_to(&mut self, byte_pos: usize) -> Result<(), TextError>

Set the iterator to this byte-position.

This is a byte position for the underlying complete text, not an index into the iterated slice. Nevertheless, the byte_pos must not exceed the bounds of the slice.

May panic if this is not a char boundary. May panic if the offset is not within the slice-bounds.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors