pub struct Popup;Expand description
With the latest enhancement of Focus this is obsolete.
Focus collects all the areas of widgets and containers and can set a z-index
for each area. With this information it runs a hit-test for each mouse event
and sets and sets the mouse-focus flag for each widget and container.
This works well with popups and overlapping widgets. This makes the
differentiation between regular widgets and widgets that might show a popup
that overlaps other widgets obsolete.
If you don’t use Focus you will still have to consider the information below.
Obsoleted
Popup/Overlays are a bit difficult to handle, as there is no z-order/area tree, which would direct mouse interactions. We can simulate a z-order in the event-handler by trying the things with a higher z-order first.
If a widget might show a popup, you have to call its event-handling
before any other widgets that might be (partially) hidden behind the
widget. This applies for e.g. Menubar, Choice and ComboBox.
To make this difference visible in the application code, these widgets
use Popup as marker for their event-handling instead of Regular.
If you implement a widget with a popup, you must make sure to consume all mouse-events within the widget area to prevent any interaction with a hidden widget.